@@ -21,20 +21,20 @@ def action_handler(trigger_event, configuration, **kwargs):
     try:
         kwargs["trigger_event"] = trigger_event
         action_result = action(**kwargs)
-        log.info("The action {} triggered by {} ended successfully.".format(action, trigger_event))
-    except Exception as exception:  # pylint: disable=broad-except
-        log.error("The action {} triggered by {} failed.".format(action, trigger_event))
+        log.info("The action %s triggered by %s ended successfully.", action, trigger_event)
+    except Exception:  # pylint: disable=broad-except
+        log.exception("The action %s triggered by %s failed", action, trigger_event)
 
         if not configuration.get("fail_silently"):
-            raise exception
+            raise
 
     return action_result
 
 
 def action_lookup(module_name, action):
     """
-    Function that returns a function defined in path, if the path is not find then a default action is
-    returned.
+    Function that returns a function defined in path,
+    if the path is not find then a default action is returned.
     The path must look like: eox_hooks.actions.default_logging
     Where eox_hooks.actions is module_name and action_name is default_logging
     """
@@ -42,14 +42,9 @@ def action_lookup(module_name, action):
         module = import_module(module_name)
         return getattr(module, action)
     except ImportError:
-        message = "The module {} with the action {} does not exist.".format(
-            module_name,
-            action,
-        )
+        message = f"The module {module_name} with the action {action} does not exist."
     except AttributeError:
-        message = "The action {} does not exist in the module {}.".format(
-            action,
-            module.__name__,
-        )
+        message = f"The action {action} does not exist in the module {module.__name__}."
 
     log.error(message)
+    return None
